#!/bin/sh
# The next line restarts using nmrWish \
exec nmrWish "$0" -notk -- "$@"

set auto_path "[split $env(TCLPATH) :] $auto_path"

set ARGV      [concat $argv0 $argv]
set ARGC      [llength $ARGV]

# tcl script runs within nmrwish/nmrPipe environment.  David Bryce March 2004. dbryce@speck.niddk.nih.gov

if {[flagLoc $ARGV -help]} \
   {
    puts "Apply Extended Histogram Method (EHM) to estimate alignment tensor magnitude, Da(NH), and rhombicity, R."
    puts "This tcl script is currently set up only for protein 1DNH, 1DCC, 1DNC RDCs."
    puts "Input is in the standard nmrPipe/Dynamo RDC table format."
    puts "Currently set up to generate synthetic dipolar couplings at one-degree increments in each plane."
    puts ""
    puts "Bryce and Bax, J. Biomol. NMR 2004, 28, 273-287."
    puts ""
    puts "Important: In the current implementation, Weight column, W, must be normalized to DNH, i.e., W(NH) = 1.000, W(CC) ~ 5.05, W(NC) ~ 8.33"
    puts " -in     inName    \[dObsA.tab\]      	Input Table."
    puts " -out    outName   \[dEHMA.tab\]     		Output Table."
    puts " -sum    summary   \[EHMsummary.txt\] 	Alignment tensor results summarized."
    puts " -verb                            		Verbose Mode ON (Default)."
    puts " -noverb                          		Verbose Mode OFF."
exit 1
   }

set inName   dObsA.tab 
set outName  [open dEHMA.tab w]
set sumName  [open EHMsummary.txt w]
set verbose  1

getArgD $ARGV -in    inName
getArgD $ARGV -out   outName

if {[flagLoc $ARGV -verb]}   {set verbose 1}
if {[flagLoc $ARGV -noverb]} {set verbose 0}

#
#-------------------------------------------------------------------------

#------------------------------------------------------------------------

if {![file exists $inName]} \
   {
    puts stderr "Error Finding Input File $inName"
    exit 1
   }





set dTab    	[gdbRead table -in $inName]
set eList   	[gdbGetInfo $dTab -parms entries]

set dzzall      0
set dzz 	0
set dyyall      0
set dyy         0
set da          0
set daall	0
set daehm       0
set dafinal     0
set d1temp	0
set d2temp	0
set d3temp	0
set d4temp	0
set sdc1temp	0
set sdc2temp	0
set sdc3temp	0
set sdc4temp	0

set dnh		0
set dcc		0
set dnc		0

set dinh	-21585.20
set dicc	4284.77
set dinc	-2609.05

set ampl	0
set psigood     999
set offset      999

set Rall        999
set R           999
set Rehm        999
set Rfinal      999

puts $outName "VARS   RESID_I RESNAME_I ATOMNAME_I RESID_J RESNAME_J ATOMNAME_J DI D_OBS D D_DIFF DD W TEXT"
puts $outName "FORMAT  %4d %4s %4s %4d %4s %4s %9.2f %9.3f %9.3f %9.3f %.2f %.2f %6s"
puts $outName ""

foreach entry $eList \
   {
    set resIDI 	[gdbGet $entry RESID_I]
    set resIDJ 	[gdbGet $entry RESID_J]
    set atomI  	[gdbGet $entry ATOMNAME_I]
    set atomJ  	[gdbGet $entry ATOMNAME_J]   
    set rNameI	[gdbGet $entry RESNAME_I]
    set rNameJ 	[gdbGet $entry RESNAME_J]   
    set d      	[gdbGet $entry D]
    set dd      [gdbGet $entry DD]
    set w       [gdbGet $entry W]
    set psigood     999

if {$atomI != "HA#" && $atomJ != "HA#"} then \
{
if {[expr $d*$w] >= [expr $d1temp]} then \
                {set d1temp ($d*$w)}

if {[expr $d*$w] < [expr $d2temp]} then \
                {set d2temp ($d*$w)}

if {[expr $d1temp*$d1temp] > [expr $d2temp*$d2temp]} then \
                {set dzzall ($d1temp)} else \
                {set dzzall ($d2temp)}
			}
				

if {$atomI == "N" && $atomJ == "HN" || $atomI == "HN" && $atomJ == "N"} then \
	{ \
	   foreach entry $eList \
                {
			set resIDI2 	[gdbGet $entry RESID_I]
    			set resIDJ2 	[gdbGet $entry RESID_J]
   			set atomI2  	[gdbGet $entry ATOMNAME_I]
 			set atomJ2  	[gdbGet $entry ATOMNAME_J]   
 			set rNameI2	[gdbGet $entry RESNAME_I]
 			set rNameJ2 	[gdbGet $entry RESNAME_J]   
 			set d2      	[gdbGet $entry D]
 			set dd2      	[gdbGet $entry DD]
 			set w2       	[gdbGet $entry W]
		
                 if {$resIDI2 == [expr $resIDI-1] && $resIDJ2 == [expr $resIDJ-1] && $atomI2 == "CA" && $atomJ2 == "C" || \
                     $resIDI2 == [expr $resIDI-1] && $resIDJ2 == [expr $resIDJ-1] && $atomI2 == "C" && $atomJ2 == "CA" } then \
			{ \
				foreach entry $eList \
					{
					set resIDI3 	[gdbGet $entry RESID_I]
    					set resIDJ3 	[gdbGet $entry RESID_J]
   					set atomI3  	[gdbGet $entry ATOMNAME_I]
 					set atomJ3  	[gdbGet $entry ATOMNAME_J]   
 					set rNameI3	[gdbGet $entry RESNAME_I]
 					set rNameJ3 	[gdbGet $entry RESNAME_J]   
 					set d3      	[gdbGet $entry D]
 					set dd3      	[gdbGet $entry DD]
 					set w3       	[gdbGet $entry W]
		  if {$resIDI3 == [expr $resIDI-1] && $resIDJ3 == [expr $resIDJ] && $atomI3 == "C" && $atomJ3 == "N" || \
                      $resIDJ3 == [expr $resIDI-1] && $resIDI3 == [expr $resIDJ] && $atomI3 == "N" && $atomJ3 == "C" } then \
		{ \
		
                if {[expr $d*$w] >= [expr $d3temp]} then \
                {set d3temp $d*$w} 
 
                if {[expr $d*$w] < [expr $d4temp]} then \
                {set d4temp $d*$w}

                if {[expr $d2*($w2/$w)] >= [expr $d3temp]} then \
                {set d3temp $d2*($w2/$w)}
                if {[expr $d2*($w2/$w)] < [expr $d4temp]} then \
                {set d4temp $d2*($w2/$w)}

		if {[expr $d3*($w3/$w)] >= [expr $d3temp]} then \
                {set d3temp $d3*($w3/$w)}

                if {[expr $d3*($w3/$w)] < [expr $d4temp]} then \
                {set d4temp $d3*($w3/$w)}


		if {abs([expr $d3temp]) > abs([expr $d4temp])} then \
                {set dzz ($d3temp)} else \
                {set dzz ($d4temp)}

# ************* Start EHM Code *******************************************
puts "Generating synthetic dipolar couplings for plane #$resIDJ" 
# DNH RDC is in variable 'd'
# DCC RDC is in variable 'd2'
# DNC RDC is in variable 'd3'

set dnh [expr $d*$w]
set dcc [expr $d2*$w2]
set dnc [expr $d3*$w3]

set phi1 	0.99064888	
set phi2	2.09439510 	

set q12		[expr ($dcc-$dnc)/($dnh-$dcc)]
set q23		[expr ($dnc-$dnh)/($dcc-$dnc)]
set q31		[expr ($dnc-$dnh)/($dnh-$dcc)]


# Solve for psi2 using equation 14
set a1		((-1-$q12)*cos(2*$phi1)+cos(2*$phi2)+$q12)	
set a2		[expr pow($a1,2)]
set a3		((1+$q12)*sin(2*$phi1)-sin(2*$phi2))
set a4		[expr pow($a3,2)]
set a5		sqrt($a2+$a4)
set a6		((1+$q12)*sin(2*$phi1)-sin(2*$phi2))
set a7		[expr ($a6/$a5)]
set a8		[expr acos($a7)]

# Two solutions for psi2 from equation 14
set a9		[expr (0.5*($a8+3.14159265))]
set a10		[expr (-0.5*($a8+3.14159265))]

# Solve for psi2 using equation 15
set b1		($q23*sin(2*$phi1)-(1+$q23)*sin(2*$phi2))
set b2		[expr pow($b1,2)]
set b3		($q23*cos(2*$phi1)-(1+$q23)*cos(2*$phi2)+1)
set b4		[expr pow($b3,2)]
set b5		sqrt($b2+$b4)
set b6		($q23*sin(2*$phi1)-(1+$q23)*sin(2*$phi2))
set b7		[expr ($b6/$b5)]
set b8		[expr acos($b7)]

# Two solutions for psi2 from equation 15
set b9		[expr (0.5*($b8+3.14159265))]	
set b10		[expr (-0.5*($b8+3.14159265))]

# determine DNHmaxAZZg2 from equation 8 and psi2 = a9
set c1		[expr ($dnh-$dcc)]
set c2		(cos(2*$a9)-cos(2*($a9+$phi1)))
set c3		[expr ($c1/$c2)]

set c4		[expr $dnh-$c3*cos(2*$a9)]
set c5		[expr $dcc-$c3*cos(2*($a9+$phi1))]
set c6		[expr $dnc-$c3*cos(2*($a9+$phi2))]

if {[expr abs([expr $c4-$c5])] < [expr 0.01] && [expr abs([expr $c5-$c6])] < [expr 0.01] && [expr abs([expr $c6-$c4])] < [expr 0.01]} then \
	{set psigood $a9}

# determine DNHmaxAZZg2 from equation 8 and psi2 = a10
set e1		[expr ($dnh-$dcc)]
set e2		(cos(2*$a10)-cos(2*($a10+$phi1)))
set e3		[expr ($e1/$e2)]

set e4		[expr $dnh-$e3*cos(2*$a10)]
set e5		[expr $dcc-$e3*cos(2*($a10+$phi1))]
set e6		[expr $dnc-$e3*cos(2*($a10+$phi2))]

if {[expr abs([expr $e4-$e5])] < [expr 0.01] && [expr abs([expr $e5-$e6])] < [expr 0.01] && [expr abs([expr $e6-$e4])] < [expr 0.01]} then \
	{set psigood $a10}

# determine DNHmaxAZZg2 from equation 8 and psi2 = b9
set f1		[expr ($dnh-$dcc)]
set f2		(cos(2*$b9)-cos(2*($b9+$phi1)))
set f3		[expr ($f1/$f2)]

set f4		[expr $dnh-$f3*cos(2*$b9)]
set f5		[expr $dcc-$f3*cos(2*($b9+$phi1))]
set f6		[expr $dnc-$f3*cos(2*($b9+$phi2))]

if {[expr abs([expr $f4-$f5])] < [expr 0.01] && [expr abs([expr $f5-$f6])] < [expr 0.01] && [expr abs([expr $f6-$f4])] < [expr 0.01]} then \
	{set psigood $b9}


# determine DNHmaxAZZg2 from equation 8 and psi2 = b10
set g1		[expr ($dnh-$dcc)]
set g2		(cos(2*$b10)-cos(2*($b10+$phi1)))
set g3		[expr ($g1/$g2)]

set g4		[expr $dnh-$g3*cos(2*$b10)]
set g5		[expr $dcc-$g3*cos(2*($b10+$phi1))]
set g6		[expr $dnc-$g3*cos(2*($b10+$phi2))]

if {[expr abs([expr $g4-$g5])] < [expr 0.01] && [expr abs([expr $g5-$g6])] < [expr 0.01] && [expr abs([expr $g6-$g4])] < [expr 0.01]} then \
	{set psigood $b10}


if {$psigood == $a9} then {set ampl $c3}
if {$psigood == $a10} then {set ampl $e3}
if {$psigood == $b9} then {set ampl $f3}
if {$psigood == $b10} then {set ampl $g3}

if {$psigood == $a9} then {set offset $c4}
if {$psigood == $a10} then {set offset $e4}
if {$psigood == $b9} then {set offset $f4}
if {$psigood == $b10} then {set offset $g4}

#puts "psigood $psigood"
#puts "amplitude $ampl"
#puts "offset $offset"

set text EXPT
set pincr [expr (3.14159265/180)]

set fmt "%4d %4s %4s %4d %4s %4s %9.2f %9.3f %9.3f %9.3f %.2f %.2f %6s"
		puts $outName [format $fmt $resIDI $rNameI $atomI $resIDJ $rNameJ $atomJ $dinh $d $d 0 $dd $w $text]
                puts $outName [format $fmt $resIDI2 $rNameI2 $atomI2 $resIDJ2 $rNameJ2 $atomJ2 $dicc $d2 $d2 0 $dd2 $w2 $text]
                puts $outName [format $fmt $resIDI3 $rNameI3 $atomI3 $resIDJ3 $rNameJ3 $atomJ3 $dinc $d3 $d3 0 $dd3 $w3 $text]

# ****************** Determine coupling perpendicular to the peptide plane.
set perp 	[expr (-2*$offset)]
set text	PERP
		
		puts $outName [format $fmt $resIDI $rNameI $atomI $resIDJ $rNameJ $atomJ $dinh $perp $perp 0 $dd $w $text]

# ******************  Generate SDCs 
for {set p 0} {$p <= 181} {incr p 1} \
	{
		if {$p < 181} then \
                {
		set sdc 	[expr $offset+$ampl*cos(2*($psigood+($p*3.14159265/180)))]
		
		#set sdc1	[expr $offset+$ampl*cos(2*($psigood))]
		#set sdc2	[expr $offset+$ampl*cos(2*($psigood+1.04719755))]
		#set sdc3	[expr $offset+$ampl*cos(2*($psigood+2.09439510))]

		
		set text "SDC $p"
		puts $outName [format $fmt $resIDI $rNameI $atomI $resIDJ $rNameJ $atomJ $dinh $sdc $sdc 0 $dd $w $text]
		} \
		else {set sdc $perp}

			if {[expr $sdc*$w] >= [expr $sdc1temp]} then \
                		{set sdc1temp ($sdc*$w)}

			if {[expr $sdc*$w] < [expr $sdc2temp]} then \
               			 {set sdc2temp ($sdc*$w)}

			if {[expr $sdc1temp*$sdc1temp] > [expr $sdc2temp*$sdc2temp]} then \
               			 {set dzzehm ($sdc1temp)} else \
             			   {set dzzehm ($sdc2temp)}
	}


# ******************  Select best alignment tensor parameters from all planes

			if {[expr $sdc1temp] >= [expr $sdc3temp]} then \
                		{set sdc3temp ($sdc1temp)}


			if {[expr $sdc2temp] >= [expr $sdc3temp]} then \
                		{set sdc3temp ($sdc2temp)}

			if {[expr $sdc1temp] < [expr $sdc4temp]} then \
               			 {set sdc4temp ($sdc1temp)}

			if {[expr $sdc2temp] < [expr $sdc4temp]} then \
               			 {set sdc4temp ($sdc2temp)}

			if {[expr abs([expr $sdc4temp])] < [expr abs([expr $sdc3temp])]} then \
     				{set dzzehm [expr $sdc3temp]} else \
				{set dzzehm [expr $sdc4temp]}

			if {([expr $sdc3temp] == [expr $dzzehm])} then \
				{set dyyehm $sdc4temp} else \
				{set dyyehm $sdc3temp}



#puts "best dzzehm $dzzehm"
#puts " sdc3temp $sdc3temp"
#puts " sdc4temp $sdc4temp"



		
                }}} \
   		}}
         }

if {[expr $d1temp] == [expr $dzzall]} then \
    {set dyyall $d2temp} else \
    {set dyyall $d1temp}

if {[expr $d3temp] == [expr $dzz]} then \
    {set dyy $d4temp} else \
    {set dyy $d3temp}




# ********** Determine Alignment Tensor Parameters *************

set da 		[expr $dzz/2]
set R           [expr (-0.66667*(1+($dyy/$da)))]
if {$R < 0.0} then {set R 0.0}


set daaal 	[expr $dzzall/2]
set Rall        [expr (-0.66667*(1+($dyyall/$daaal)))]
if {$Rall < 0.0} then {set Rall 0.0}

set daehm       [expr $dzzehm/2]
set Rehm	[expr (-0.66667*(1+($dyyehm/$daehm)))]
if {$Rehm < 0.0} then {set Rehm 0.0}

if  {[expr abs([expr $dzzall])] > [expr abs([expr $dzzehm])]} then {set dzzfinal $dzzall} else {set dzzfinal $dzzehm}
if  {[expr abs([expr $dyyall])] > [expr abs([expr $dyyehm])]} then {set dyyfinal $dyyall} else {set dyyfinal $dyyehm}

#puts "dyyfinal [expr $dyyfinal]"
#puts "dzzfinal [expr $dzzfinal]"
#puts "dyyehm [expr $dyyehm]"
#puts "dzzehm [expr $dzzehm]"



set dafinal	[expr $dzzfinal/2]
set Rfinal	[expr (-0.66667*(1+($dyyfinal/$dafinal)))]

if {$Rfinal < 0.0} then {set Rfinal 0.0}

if {$verbose} \
   {
   set fmt "%6.3f"
puts "The alignment tensor parameters based on standard histogram approach using only triplets of 1DNH, 1DCC, 1DNC RDCs are "
puts ""
puts "        Da(NH) = [format $fmt $da] Hz; R = [format $fmt $R] (poorest estimate)." 
if {$R == 0.0} then {puts "WARNING Rhombicity likely unreliable"}
puts ""
puts ""

puts "The alignment tensor parameters based on standard histogram approach using all available RDCs is "
puts ""
puts "        Da(NH) = [format $fmt $daaal] Hz; R = [format $fmt $Rall] ."
if {$Rall == 0.0} then {puts "WARNING Rhombicity likely unreliable"}
puts ""
puts ""

puts "The alignment tensor parameters based on the Extended Histogram Method applied to 1DNH, 1DCC, 1DNC RDCs are "
puts ""
puts "        Da(NH) = [format $fmt $daehm] Hz; R = [format $fmt $Rehm] (summarized in dEHMA.tab)."
if {$Rehm == 0.0} then {puts "WARNING Rhombicity likely unreliable"}
puts ""
puts ""

puts "The alignment tensor parameters based on the EHM plus all other available RDCs is "
puts ""
puts "        Da(NH) = [format $fmt $dafinal] Hz; R = [format $fmt $Rfinal] (best estimate)."
if {$Rfinal == 0.0} then {puts "WARNING Rhombicity likely unreliable"}
puts ""

#puts "Type 'showDC.tcl -in dEHMA.tab -nH 30 -single' to display extended histogram."
 	}

   set fmt "%6.3f"
puts $sumName  "The alignment tensor parameters based on standard histogram approach using only triplets of 1DNH, 1DCC, 1DNC RDCs are "
puts $sumName ""
puts $sumName "        Da(NH) = [format $fmt $da] Hz; R = [format $fmt $R] (poorest estimate)." 
puts $sumName ""
puts $sumName ""

puts $sumName "The alignment tensor parameters based on standard histogram approach using all available RDCs is "
puts $sumName ""
puts $sumName "        Da(NH) = [format $fmt $daaal] Hz; R = [format $fmt $Rall] ."
puts $sumName ""
puts $sumName ""

puts $sumName "The alignment tensor parameters based on the Extended Histogram Method applied to 1DNH, 1DCC, 1DNC RDCs are "
puts $sumName ""
puts $sumName "        Da(NH) = [format $fmt $daehm] Hz; R = [format $fmt $Rehm]  (summarized in dEHMA.tab)."
puts $sumName ""
puts $sumName ""

puts $sumName "The alignment tensor parameters based on the EHM plus all other available RDCs are "
puts $sumName ""
puts $sumName "        Da(NH) = [format $fmt $dafinal] Hz; R = [format $fmt $Rfinal] (best estimate)."
puts $sumName ""

exit
