#!/bin/sh
# The next line restarts using nmrWish \
exec nmrWish "$0" -- -notk "$@"

set auto_path   "[split $env(TCLPATH) :] $auto_path"
set ARGV         [concat $argv0 $argv]
set ARGC         [llength $ARGV]

if {[flagLoc $ARGV -help]} \
   {
    puts stderr "Print SUM of numbers in four single-column text files;"
    puts stderr "the files must have the same number of entries:"
    puts stderr " -aName aTextName   \[a.txt\]"
    puts stderr " -bName bTextName   \[b.txt\]"
    puts stderr " -cName cTextName   \[c.txt\]"   
    puts stderr " -dName dTextName   \[d.txt\]"
    puts stderr " -out   outTextName \[None\]"
    exit 1
   }

set aName   a.txt
set bName   b.txt
set cName   c.txt
set dName   d.txt
set outName e.txt

getArgD $ARGV -aName aName
getArgD $ARGV -bName bName
getArgD $ARGV -cName cName
getArgD $ARGV -dName dName
getArgD $ARGV -out   outName

#
#-----------------------------------------------------------------------

set error [catch {set aUnit [open $aName r]}]

if {$error} \
   {
    puts stderr "Error opening file $aName"
    exit 1
   }

set error [catch {set bUnit [open $bName r]}]

if {$error} \
   {
    puts stderr "Error opening file $bName"
    exit 1
   }

set error [catch {set cUnit [open $cName r]}]

if {$error} \
   {
    puts stderr "Error opening file $cName"
    exit 1
   }

set error [catch {set dUnit [open $dName r]}]

if {$error} \
   {
    puts stderr "Error opening file $dName"
    exit 1
   }

set aList ""
set bList ""
set cList ""
set dList ""

set nA 0
set nB 0
set nC 0
set nD 0

while {[gets $aUnit line] >= 0} \
   {
    incr nA

    set val [lindex $line 0]
    
    if {![llength $val]} \
       {
        puts stderr "Missing data on line $nB of file $aName"
        exit 1
       }

    lappend aList $val
   }

close $aUnit

while {[gets $bUnit line] >= 0} \
   {
    incr nB

    set val [lindex $line 0]
    
    if {![llength $val]} \
       {
        puts stderr "Missing data on line $nB of file $bName"
        exit 1
       }

    lappend bList $val
   }

close $bUnit

while {[gets $cUnit line] >= 0} \
   {
    incr nC

    set val [lindex $line 0]
    
    if {![llength $val]} \
       {
        puts stderr "Missing data on line $nC of file $cName"
        exit 1
       }

    lappend cList $val
   }

close $cUnit

while {[gets $dUnit line] >= 0} \
   {
    incr nD

    set val [lindex $line 0]
    
    if {![llength $val]} \
       {
        puts stderr "Missing data on line $nD of file $dName"
        exit 1
       }

    lappend dList $val
   }

close $dUnit





if {$nA != $nB} \
   {
    puts "Error: the file sizes are different ($nA and $nB lines)."
    exit 1
   }


if {$nB != $nC} \
   {
    puts "Error: the file sizes are different ($nB and $nC lines)."
    exit 1
   }

if {$nC != $nD} \
   {
    puts "Error: the file sizes are different ($nC and $nD lines)."
    exit 1
   }


if {$nA != $nD} \
   {
    puts "Error: the file sizes are different ($nA and $nD lines)."
    exit 1
   }

if {$nB != $nD} \
   {
    puts "Error: the file sizes are different ($nB and $nD lines)."
    exit 1
   }

if {$nA != $nC} \
   {
    puts "Error: the file sizes are different ($nA and $nC lines)."
    exit 1
   }

if {![strcasecmp $outName None]} \
   {
    set outUnit stdout
   } \
else \
   {
    set error [catch {set outUnit [open $outName w]}]

    if {$error} \
       {
        puts stderr "Error opening output file $outName"
        exit 1
       }
   }

for {set i 0} {$i < $nA} {incr i} \
   {
    set a   [lindex $aList $i]
    set b   [lindex $bList $i]
    set c   [lindex $cList $i]
    set d   [lindex $dList $i]
    set sum   [expr {$a}]
    if {$b>$sum} then {set sum [expr {$b}]}
    if {$c>$sum} then {set sum [expr {$c}]}
    if {$d>$sum} then {set sum [expr {$d}]} 
    puts $outUnit [format "% 8.3f" $sum]
   }

if {[strcasecmp $outName None]} {close $outUnit}

exit

