#!/bin/sh
# The next line restarts using nmrWish \
exec nmrWish "$0" -- "$@"

#
# To suppress window: exec nmrWish "$0" -notk -- "$@"
# To iconify window:  wm iconify .

set auto_path "[split $env(TCLPATH) :] $auto_path"
set ARGV      [concat $argv0 $argv]
set ARGC      [llength $ARGV]

set pdbName ref.pdb
set dcName  dObsA.tab  

set daMin   1.0e-4
set daMax   5.0e-4
set daCount 32 

set rhMin  0.00 
set rhMax   0.66666
set rhCount 32 

if {[flagLoc $ARGV -help]} \
   {
    puts "DC Simulation Grid Search:"
    puts " -pdb     pdbName  \[ref.pdb\]    PDB Input File."
    puts " -dc      dcName   \[dObsA.tab\]  DC Input File."
    puts " -daMin   daMin    \[1.0e-4\]     Da Min for Grid Search."
    puts " -daMax   daMax    \[5.0e-4\]     Da Max for Grid Search."
    puts " -daCount daCount  \[16\]         Number of Da Values for Grid."
    puts " -rhMin   rhMin    \[0.000\]      Rh Min for Grid Search."
    puts " -rhMax   rhMax    \[0.666\]      Rh Max for Grid Search."
    puts " -rhCount rhCount  \[16\]         Number of Rh Values for Grid."
    exit 1
   }

getArgD $ARGV -pdb     pdbName
getArgD $ARGV -dc      dcName

getArgD $ARGV -daMin   daMin
getArgD $ARGV -daMax   daMax
getArgD $ARGV -daCount daCount

getArgD $ARGV -rhMin   rhMin
getArgD $ARGV -rhMax   rhMax
getArgD $ARGV -rhCount rhCount

#
#----------------------------------------------------------------

dynInit -fast

set pdbSrc [dynRead -pdb -in $pdbName]
set dcSrc  [dynRead -dc  -in $dcName]

set daRange [expr $daMax - $daMin]
set rhRange [expr $rhMax - $rhMin]

set outUnit [open test.out w]

for {set i 0} {$i < $daCount} {incr i} \
   {
    set da [expr $daMin + $daRange*$i/($daCount - 1)]
puts stdout [expr $i]
    for {set j 0} {$j < $rhCount} {incr j} \
       {
        set rh [expr $rhMin + $rhRange*$j/($rhCount - 1)]
        set dr [expr $da*$rh]

#
# dInfo:
#  rms chi2 q r n da dr eulerCount eulerSets nActual
set q2 40000
        set dInfo \
         [dynSimulate -fit -dc $dcSrc -src $pdbSrc -dadr -da $da -dr $dr -qr -retry 2 -auto]  
         
        set q1   [lindex $dInfo 1]

set dInfo \
         [dynSimulate -fit -psi 45.0 -theta 45.0 -phi -45.0 -dc $dcSrc -src $pdbSrc -dadr -da $da -dr $dr -qr]  

              set q2 [lindex $dInfo 1]
              if {$q1<$q2} {set q2 [expr $q1*1]}

        
#      puts $outUnit [format "%.7f" $da]
#      puts $outUnit [format "%.7f" $rh] 

         puts $outUnit [format "%.7f" $q2] 
        

       }
   }

exit
