REM *******************************************************************
REM Sept. 10, 2003
REM David L. Bryce and Ad Bax
REM
REM Application of Correlated Residual Dipolar Couplings to the
REM Determination of the Molecular Alignment Tensor Magnitude
REM of Oriented Proteins and Nucleic Acids.
REM
REM J. Biomol. NMR, submitted.
REM *******************************************************************


REM Define angles phi1 and phi2, in degrees
a2d = 56.76
a3d = 120!





10 REM   ***
20 REM
25 pi = 3.1415926535#
30 CLS
40

REM Open data files

50 OPEN "data1.txt" FOR INPUT AS #1
60 INPUT #1, ncoupl
OPEN "out1.txt" FOR OUTPUT AS #2
OPEN "hist1.txt" FOR OUTPUT AS #4


REM Read RDCs
70 FOR i = 1 TO ncoupl
80 INPUT #1, y1, y2, y3


g = a2d * pi / 180
h = a3d * pi / 180

x = (y3 - y1) / (y2 - y3)

REM solve for phase psi2 (from above x)

REM denominator

t1 = x ^ 2 * COS(2 * g) ^ 2
t2 = 2 * x * COS(2 * g) * COS(1 - 2 * h)
t3 = COS(1 - 2 * h) ^ 2
t4 = 2 * x ^ 2 * COS(2 * g) * COS(2 * h)
t5 = 2 * x * COS(1 - 2 * h) * COS(2 * h)
t6 = x ^ 2 * COS(2 * h) ^ 2
t7 = x ^ 2 * SIN(2 * g) ^ 2
t8 = 2 * x * SIN(2 * g) * SIN(2 * h)
t9 = 2 * x ^ 2 * SIN(2 * g) * SIN(2 * h)
t10 = SIN(2 * h) ^ 2
t11 = 2 * x * SIN(2 * h) ^ 2
t12 = x ^ 2 * SIN(2 * h) ^ 2
t13 = 2 * x * COS(2 * g)
t14 = 2 * COS(2 * h)
t15 = 2 * x * COS(2 * h)
t16 = 2 * x * COS(2 * g) * COS(2 * h)
t17 = COS(2 * h) ^ 2
t18 = 2 * x * COS(2 * h) ^ 2

ttot = 1 + t13 + t1 - t14 - t15 - t16 - t4 + t17 + t18 + t6 + t7 - t8 - t9 + t10 + t11 + t12
troot = SQR(ttot)


REM numerator

n1 = x ^ 2 * SIN(2 * g) ^ 2
n2 = 2 * x * SIN(2 * g) * SIN(2 * h)
n3 = 2 * x ^ 2 * SIN(2 * g) * SIN(2 * h)
n4 = SIN(2 * h) ^ 2
n5 = 2 * x * SIN(2 * h) ^ 2
n6 = x ^ 2 * SIN(2 * h) ^ 2

ntot = n1 - n2 - n3 + n4 + n5 + n6
nroot = SQR(ntot)

REM calculate argument of arccos
arg = -1 * (nroot / troot)
REM PRINT "arg"; arg

REM calculate f
f2 = -.5 * (ATN((SQR(1 - arg ^ 2)) / arg) + pi)
f1 = .5 * (ATN((SQR(1 - arg ^ 2)) / (arg)) + pi)


REM PRINT "Possible phase 1:"; f2
REM PRINT "Possible phase 2:"; f1


REM next set of equations
x = (y2 - y3) / (y1 - y2)

REM find f from eq1 over eq2
b1 = SIN(2 * g) ^ 2
b2 = 2 * x * SIN(2 * g) ^ 2
b3 = x ^ 2 * SIN(2 * g) ^ 2
b4 = 2 * SIN(2 * g) * SIN(2 * h)
b5 = 2 * x * SIN(2 * g) * SIN(2 * h)
b6 = SIN(2 * h) ^ 2

b7 = 2 * x * COS(2 * g)
b9 = x ^ 2
b8 = 2 * x ^ 2 * COS(2 * g)
b10 = COS(2 * g) ^ 2
b11 = 2 * x * COS(2 * g) ^ 2
b12 = x ^ 2 * COS(2 * g) ^ 2
b13 = 2 * x * COS(2 * h)
b14 = 2 * COS(2 * g) * COS(2 * h)
b15 = 2 * x * COS(2 * g) * COS(2 * h)
b16 = COS(2 * h) ^ 2
b17 = SIN(2 * g) ^ 2
b18 = 2 * x * SIN(2 * g) ^ 2
b19 = x ^ 2 * SIN(2 * g) ^ 2
b20 = 2 * SIN(2 * g) * SIN(2 * h)
b21 = 2 * x * SIN(2 * g) * SIN(2 * h)
b22 = SIN(2 * h) ^ 2

wtop = SQR(b1 + b2 + b3 - b4 - b5 + b6)
wbot = SQR(b9 - b7 - b8 + b10 + b11 + b12 + b13 - b14 - b15 + b16 + b17 + b18 + b19 - b20 - b21 + b22)

argb = wtop / wbot
REM PRINT "argb"; argb

f3 = .5 * (ATN((SQR(1 - argb ^ 2)) / argb) + pi)
f4 = -.5 * (ATN((SQR(1 - argb ^ 2)) / argb) + pi)
REM PRINT "Possible phase 3"; f3
REM PRINT "Possible phase 4"; f4



REM test f1
f = f1

REM find B
topB = y1 - y2
botB = COS(2 * f) - COS(2 * (f + g))
B = topB / botB
REM PRINT "B is "; B


REM find A
A1 = y1 - B * COS(2 * f)
A2 = y2 - B * COS(2 * (f + g))
A3 = y3 - B * COS(2 * (f + h))
REM PRINT "Three determinations of A based on f1 give:"; A1, A2, A3
IF ABS(A1 - A2) < .01 AND ABS(A2 - A3) < .01 AND ABS(A3 - A1) < .01 THEN fgood = f1


REM test f2
f = f2

REM find B
topB = y1 - y2
botB = COS(2 * f) - COS(2 * (f + g))
B = topB / botB
REM PRINT "B is "; B


REM find A
A1 = y1 - B * COS(2 * f)
A2 = y2 - B * COS(2 * (f + g))
A3 = y3 - B * COS(2 * (f + h))
REM PRINT "Three determinations of A based on f1 give:"; A1, A2, A3
IF ABS(A1 - A2) < .01 AND ABS(A2 - A3) < .01 AND ABS(A3 - A1) < .01 THEN fgood = f2

REM test f3
f = f3

REM find B
topB = y1 - y2
botB = COS(2 * f) - COS(2 * (f + g))
B = topB / botB
REM PRINT "B is "; B


REM find A
A1 = y1 - B * COS(2 * f)
A2 = y2 - B * COS(2 * (f + g))
A3 = y3 - B * COS(2 * (f + h))
REM PRINT "Three determinations of A based on f1 give:"; A1, A2, A3
IF ABS(A1 - A2) < .01 AND ABS(A2 - A3) < .01 AND ABS(A3 - A1) < .01 THEN fgood = f3

REM test f4
f = f4

REM find B
topB = y1 - y2
botB = COS(2 * f) - COS(2 * (f + g))
B = topB / botB
REM PRINT "B is "; B


REM find A
A1 = y1 - B * COS(2 * f)
A2 = y2 - B * COS(2 * (f + g))
A3 = y3 - B * COS(2 * (f + h))
REM PRINT "Three determinations of A based on f1 give:"; A1, A2, A3
IF ABS(A1 - A2) < .01 AND ABS(A2 - A3) < .01 AND ABS(A3 - A1) < .01 THEN fgood = f4

REM continue with best f
REM PRINT "Correct phase f is:"; fgood
f = fgood

REM find B
topB = y1 - y2
botB = COS(2 * f) - COS(2 * (f + g))
B = topB / botB
REM PRINT "B is "; B


REM find A
A1 = y1 - B * COS(2 * f)
A2 = y2 - B * COS(2 * (f + g))
A3 = y3 - B * COS(2 * (f + h))
REM PRINT "Three determinations of A based on f1 give:"; A1, A2, A3




REM try to reproduce input data
w1 = y1
w2 = A2 + B * COS(2 * (f + g))
w3 = A3 + B * COS(2 * (f + h))

PRINT "*******************************"
PRINT "Dataset #"; i
PRINT "Attempt to reproduce input data: "; w1, w2, w3; " Hz"



REM find average coupling in this plane
c1 = y1
c2 = A2 + B * COS(2 * (f + pi / 3))
c3 = A3 + B * COS(2 * (f + 2 * pi / 3))
REM PRINT "c1,c2,c3"; c1, c2, c3
ave = (c1 + c2 + c3) / 3
PRINT "average coupling in plane:"; ave
dperp = -2 * ave
PRINT "perpendicular coupling:"; dperp


300 FOR p = 0 TO 3.14159265# STEP .0174533#
310 r1 = A1 + B * COS(2 * (f + p))
320 WRITE #2, r1
330 NEXT p
340 WRITE #2, dperp
NEXT i

CLOSE #1
CLOSE #2
Total = (181 * ncoupl) + ncoupl
dmax = 0
dmin = 0

OPEN "out1.txt" FOR INPUT AS #2
FOR j = 1 TO Total
INPUT #2, d
IF d > dmax THEN dmax = d
IF d < dmin THEN dmin = d
NEXT j

IF ABS(dmin) > ABS(dmax) THEN da = (1 / 2) * dmin
IF ABS(dmin) < ABS(dmax) THEN da = (1 / 2) * dmax

CLOSE #2

REM build histogram data
histmin = 1.25 * dmin
histmax = 1.25 * dmax

REM 64 bins for data

binsize = (ABS(dmin) + ABS(dmax)) / 64
OPEN "out1.txt" FOR INPUT AS #2

FOR bb = 1 TO Total
INPUT #2, v
IF v <= dmin + binsize THEN bin1 = bin1 + 1
IF v > dmin + 1 * binsize AND v <= dmin + 2 * binsize THEN bin2 = bin2 + 1
IF v > dmin + 2 * binsize AND v <= dmin + 3 * binsize THEN bin3 = bin3 + 1
IF v > dmin + 3 * binsize AND v <= dmin + 4 * binsize THEN bin4 = bin4 + 1
IF v > dmin + 4 * binsize AND v <= dmin + 5 * binsize THEN bin5 = bin5 + 1
IF v > dmin + 5 * binsize AND v <= dmin + 6 * binsize THEN bin6 = bin6 + 1
IF v > dmin + 6 * binsize AND v <= dmin + 7 * binsize THEN bin7 = bin7 + 1
IF v > dmin + 7 * binsize AND v <= dmin + 8 * binsize THEN bin8 = bin8 + 1
IF v > dmin + 8 * binsize AND v <= dmin + 9 * binsize THEN bin9 = bin9 + 1
IF v > dmin + 9 * binsize AND v <= dmin + 10 * binsize THEN bin10 = bin10 + 1
IF v > dmin + 10 * binsize AND v <= dmin + 11 * binsize THEN bin11 = bin11 + 1
IF v > dmin + 11 * binsize AND v <= dmin + 12 * binsize THEN bin12 = bin12 + 1
IF v > dmin + 12 * binsize AND v <= dmin + 13 * binsize THEN bin13 = bin13 + 1
IF v > dmin + 13 * binsize AND v <= dmin + 14 * binsize THEN bin14 = bin14 + 1
IF v > dmin + 14 * binsize AND v <= dmin + 15 * binsize THEN bin15 = bin15 + 1
IF v > dmin + 15 * binsize AND v <= dmin + 16 * binsize THEN bin16 = bin16 + 1
IF v > dmin + 16 * binsize AND v <= dmin + 17 * binsize THEN bin17 = bin17 + 1
IF v > dmin + 17 * binsize AND v <= dmin + 18 * binsize THEN bin18 = bin18 + 1
IF v > dmin + 18 * binsize AND v <= dmin + 19 * binsize THEN bin19 = bin19 + 1
IF v > dmin + 19 * binsize AND v <= dmin + 20 * binsize THEN bin20 = bin20 + 1
IF v > dmin + 20 * binsize AND v <= dmin + 21 * binsize THEN bin21 = bin21 + 1
IF v > dmin + 21 * binsize AND v <= dmin + 22 * binsize THEN bin22 = bin22 + 1
IF v > dmin + 22 * binsize AND v <= dmin + 23 * binsize THEN bin23 = bin23 + 1
IF v > dmin + 23 * binsize AND v <= dmin + 24 * binsize THEN bin24 = bin24 + 1
IF v > dmin + 24 * binsize AND v <= dmin + 25 * binsize THEN bin25 = bin25 + 1
IF v > dmin + 25 * binsize AND v <= dmin + 26 * binsize THEN bin26 = bin26 + 1
IF v > dmin + 26 * binsize AND v <= dmin + 27 * binsize THEN bin27 = bin27 + 1
IF v > dmin + 27 * binsize AND v <= dmin + 28 * binsize THEN bin28 = bin28 + 1
IF v > dmin + 28 * binsize AND v <= dmin + 29 * binsize THEN bin29 = bin29 + 1
IF v > dmin + 29 * binsize AND v <= dmin + 30 * binsize THEN bin30 = bin30 + 1
IF v > dmin + 30 * binsize AND v <= dmin + 31 * binsize THEN bin31 = bin31 + 1
IF v > dmin + 31 * binsize AND v <= dmin + 32 * binsize THEN bin32 = bin32 + 1
IF v > dmin + 32 * binsize AND v <= dmin + 33 * binsize THEN bin33 = bin33 + 1
IF v > dmin + 33 * binsize AND v <= dmin + 34 * binsize THEN bin34 = bin34 + 1
IF v > dmin + 34 * binsize AND v <= dmin + 35 * binsize THEN bin35 = bin35 + 1
IF v > dmin + 35 * binsize AND v <= dmin + 36 * binsize THEN bin36 = bin36 + 1
IF v > dmin + 36 * binsize AND v <= dmin + 37 * binsize THEN bin37 = bin37 + 1
IF v > dmin + 37 * binsize AND v <= dmin + 38 * binsize THEN bin38 = bin38 + 1
IF v > dmin + 38 * binsize AND v <= dmin + 39 * binsize THEN bin39 = bin39 + 1
IF v > dmin + 39 * binsize AND v <= dmin + 40 * binsize THEN bin40 = bin40 + 1
IF v > dmin + 40 * binsize AND v <= dmin + 41 * binsize THEN bin41 = bin41 + 1
IF v > dmin + 41 * binsize AND v <= dmin + 42 * binsize THEN bin42 = bin42 + 1
IF v > dmin + 42 * binsize AND v <= dmin + 43 * binsize THEN bin43 = bin43 + 1
IF v > dmin + 43 * binsize AND v <= dmin + 44 * binsize THEN bin44 = bin44 + 1
IF v > dmin + 44 * binsize AND v <= dmin + 45 * binsize THEN bin45 = bin45 + 1
IF v > dmin + 45 * binsize AND v <= dmin + 46 * binsize THEN bin46 = bin46 + 1
IF v > dmin + 46 * binsize AND v <= dmin + 47 * binsize THEN bin47 = bin47 + 1
IF v > dmin + 47 * binsize AND v <= dmin + 48 * binsize THEN bin48 = bin48 + 1
IF v > dmin + 48 * binsize AND v <= dmin + 49 * binsize THEN bin49 = bin49 + 1
IF v > dmin + 49 * binsize AND v <= dmin + 50 * binsize THEN bin50 = bin50 + 1
IF v > dmin + 50 * binsize AND v <= dmin + 51 * binsize THEN bin51 = bin51 + 1
IF v > dmin + 51 * binsize AND v <= dmin + 52 * binsize THEN bin52 = bin52 + 1
IF v > dmin + 52 * binsize AND v <= dmin + 53 * binsize THEN bin53 = bin53 + 1
IF v > dmin + 53 * binsize AND v <= dmin + 54 * binsize THEN bin54 = bin54 + 1
IF v > dmin + 54 * binsize AND v <= dmin + 55 * binsize THEN bin55 = bin55 + 1
IF v > dmin + 55 * binsize AND v <= dmin + 56 * binsize THEN bin56 = bin56 + 1
IF v > dmin + 56 * binsize AND v <= dmin + 57 * binsize THEN bin57 = bin57 + 1
IF v > dmin + 57 * binsize AND v <= dmin + 58 * binsize THEN bin58 = bin58 + 1
IF v > dmin + 58 * binsize AND v <= dmin + 59 * binsize THEN bin59 = bin59 + 1
IF v > dmin + 59 * binsize AND v <= dmin + 60 * binsize THEN bin60 = bin60 + 1
IF v > dmin + 60 * binsize AND v <= dmin + 61 * binsize THEN bin61 = bin61 + 1
IF v > dmin + 61 * binsize AND v <= dmin + 62 * binsize THEN bin62 = bin62 + 1
IF v > dmin + 62 * binsize AND v <= dmin + 63 * binsize THEN bin63 = bin63 + 1
IF v > dmin + 63 * binsize THEN bin64 = bin64 + 1
REM AND v <= dmin + 64 * binsize

NEXT bb
WRITE #4, dmin - 12 * binsize, 0
WRITE #4, dmin - 11 * binsize, 0
WRITE #4, dmin - 10 * binsize, 0
WRITE #4, dmin - 9 * binsize, 0
WRITE #4, dmin - 8 * binsize, 0
WRITE #4, dmin - 7 * binsize, 0
WRITE #4, dmin - 6 * binsize, 0
WRITE #4, dmin - 5 * binsize, 0
WRITE #4, dmin - 4 * binsize, 0
WRITE #4, dmin - 3 * binsize, 0
WRITE #4, dmin - 2 * binsize, 0
WRITE #4, dmin - 1 * binsize, 0

WRITE #4, dmin, bin1
WRITE #4, dmin + 1 * binsize, bin2
WRITE #4, dmin + 2 * binsize, bin3
WRITE #4, dmin + 3 * binsize, bin4
WRITE #4, dmin + 4 * binsize, bin5
WRITE #4, dmin + 5 * binsize, bin6
WRITE #4, dmin + 6 * binsize, bin7
WRITE #4, dmin + 7 * binsize, bin8
WRITE #4, dmin + 8 * binsize, bin9
WRITE #4, dmin + 9 * binsize, bin10
WRITE #4, dmin + 10 * binsize, bin11
WRITE #4, dmin + 11 * binsize, bin12
WRITE #4, dmin + 12 * binsize, bin13
WRITE #4, dmin + 13 * binsize, bin14
WRITE #4, dmin + 14 * binsize, bin15
WRITE #4, dmin + 15 * binsize, bin16
WRITE #4, dmin + 16 * binsize, bin17
WRITE #4, dmin + 17 * binsize, bin18
WRITE #4, dmin + 18 * binsize, bin19
WRITE #4, dmin + 19 * binsize, bin20
WRITE #4, dmin + 20 * binsize, bin21
WRITE #4, dmin + 21 * binsize, bin22
WRITE #4, dmin + 22 * binsize, bin23
WRITE #4, dmin + 23 * binsize, bin24
WRITE #4, dmin + 24 * binsize, bin25
WRITE #4, dmin + 25 * binsize, bin26
WRITE #4, dmin + 26 * binsize, bin27
WRITE #4, dmin + 27 * binsize, bin28
WRITE #4, dmin + 28 * binsize, bin29
WRITE #4, dmin + 29 * binsize, bin30
WRITE #4, dmin + 30 * binsize, bin31
WRITE #4, dmin + 31 * binsize, bin32
WRITE #4, dmin + 32 * binsize, bin33
WRITE #4, dmin + 33 * binsize, bin34
WRITE #4, dmin + 34 * binsize, bin35
WRITE #4, dmin + 35 * binsize, bin36
WRITE #4, dmin + 36 * binsize, bin37
WRITE #4, dmin + 37 * binsize, bin38
WRITE #4, dmin + 38 * binsize, bin39
WRITE #4, dmin + 39 * binsize, bin40
WRITE #4, dmin + 40 * binsize, bin41
WRITE #4, dmin + 41 * binsize, bin42
WRITE #4, dmin + 42 * binsize, bin43
WRITE #4, dmin + 43 * binsize, bin44
WRITE #4, dmin + 44 * binsize, bin45
WRITE #4, dmin + 45 * binsize, bin46
WRITE #4, dmin + 46 * binsize, bin47
WRITE #4, dmin + 47 * binsize, bin48
WRITE #4, dmin + 48 * binsize, bin49
WRITE #4, dmin + 49 * binsize, bin50
WRITE #4, dmin + 50 * binsize, bin51
WRITE #4, dmin + 51 * binsize, bin52
WRITE #4, dmin + 52 * binsize, bin53
WRITE #4, dmin + 53 * binsize, bin54
WRITE #4, dmin + 54 * binsize, bin55
WRITE #4, dmin + 55 * binsize, bin56
WRITE #4, dmin + 56 * binsize, bin57
WRITE #4, dmin + 57 * binsize, bin58
WRITE #4, dmin + 58 * binsize, bin59
WRITE #4, dmin + 59 * binsize, bin60
WRITE #4, dmin + 60 * binsize, bin61
WRITE #4, dmin + 61 * binsize, bin62
WRITE #4, dmin + 62 * binsize, bin63
WRITE #4, dmin + 63 * binsize, bin64
WRITE #4, dmin + 64 * binsize, 0
WRITE #4, dmin + 65 * binsize, 0
WRITE #4, dmin + 66 * binsize, 0
WRITE #4, dmin + 67 * binsize, 0
WRITE #4, dmin + 68 * binsize, 0
WRITE #4, dmin + 69 * binsize, 0
WRITE #4, dmin + 70 * binsize, 0
WRITE #4, dmin + 71 * binsize, 0
WRITE #4, dmin + 72 * binsize, 0
WRITE #4, dmin + 73 * binsize, 0
WRITE #4, dmin + 74 * binsize, 0
WRITE #4, dmin + 75 * binsize, 0


CLOSE #4


REM create csolids file
OPEN "out1.dat" FOR OUTPUT AS #5
WRITE #5, 88
WRITE #5, 1
WRITE #5, (((dmin + 75 * binsize) - (dmin - 12 * binsize)) / 88)
WRITE #5, dmin + 75 * binsize

WRITE #5, dmin - 12 * binsize


WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, bin64
WRITE #5, bin63
WRITE #5, bin62
WRITE #5, bin61
WRITE #5, bin60
WRITE #5, bin59
WRITE #5, bin58
WRITE #5, bin57
WRITE #5, bin56
WRITE #5, bin55
WRITE #5, bin54
WRITE #5, bin53
WRITE #5, bin52
WRITE #5, bin51
WRITE #5, bin50
WRITE #5, bin49
WRITE #5, bin48
WRITE #5, bin47
WRITE #5, bin46
WRITE #5, bin45
WRITE #5, bin44
WRITE #5, bin43
WRITE #5, bin42
WRITE #5, bin41
WRITE #5, bin40
WRITE #5, bin39
WRITE #5, bin38
WRITE #5, bin37
WRITE #5, bin36
WRITE #5, bin35
WRITE #5, bin34
WRITE #5, bin33
WRITE #5, bin32
WRITE #5, bin31
WRITE #5, bin30
WRITE #5, bin29
WRITE #5, bin28
WRITE #5, bin27
WRITE #5, bin26
WRITE #5, bin25
WRITE #5, bin24
WRITE #5, bin23
WRITE #5, bin22
WRITE #5, bin21
WRITE #5, bin20
WRITE #5, bin19
WRITE #5, bin18
WRITE #5, bin17
WRITE #5, bin16
WRITE #5, bin15
WRITE #5, bin14
WRITE #5, bin13
WRITE #5, bin12
WRITE #5, bin11
WRITE #5, bin10
WRITE #5, bin9
WRITE #5, bin8
WRITE #5, bin7
WRITE #5, bin6
WRITE #5, bin5
WRITE #5, bin4
WRITE #5, bin3
WRITE #5, bin2
WRITE #5, bin1
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
WRITE #5, 0
CLOSE #5


IF da = .5 * dmax THEN dopp = dmin
IF da = .5 * dmin THEN dopp = dmax

R = -(2 / 3) * (1 + (dopp / da))


OPEN "summary1.txt" FOR OUTPUT AS #3
PRINT #3, "Summary of dipolar coupling EHM generator output."
PRINT #3, " "
PRINT #3, "Total number of sets of couplings inputted: ";
WRITE #3, ncoupl
PRINT #3, "Generated Value of Da (Hz): ";
WRITE #3, da
PRINT #3, "Generated Value of the rhombicity, R: ";
WRITE #3, R
PRINT #3, " "
PRINT #3, "Generated dipolar coupling data are in OUT1.TXT"
CLOSE #3



                            PRINT
                            PRINT "***************************************"
                            PRINT "Results are summarized in 'summary1.txt'"
                            PRINT "Dipolar couplings are stored in 'out1.txt'"
                            PRINT
                            PRINT
PRINT "Summary of dipolar coupling histogram generator output."
PRINT " "
PRINT "Total number of sets of couplings inputted: ";
PRINT ncoupl
PRINT "Generated Value of Da (Hz): ";
PRINT da
PRINT "Maximum value, DZZ (Hz):"; 2 * da
PRINT "Opposite value, DYY (Hz):"; dopp
PRINT "Generated Value of the rhombicity, R: ";
PRINT R
PRINT
PRINT "************************************"








